@@ -24,15 +24,17 @@ def prompt_yes_no(ui_script, title, message):
         with ppath.open('w') as f:
             f.write(json.dumps(conf))
         # Prompt for pasphrase
-        params = "KEY1=\\{}\n".format(str(ppath))
+        params = "KEY1={}\n".format(str(ppath))
         openExtenderUI(ui_script, params, True)
         with ppath.open('r') as f:
             resp = json.loads(f.read())
+    except Exception as err:
+        return None
     finally:
         if ppath.exists():
             ppath.unlink()
 
-    return resp.get("response", False)
+    return resp.get("response")
 
 class PromptUI(UI):
     """UI for prompting yes/no."""
